@@ -132,7 +132,7 @@ module YARD
     # @see NamespaceMapper.register_separator
     class Base
       # The files the object was defined in. To add a file, use {#add_file}.
-      # @return [Array<String>] a list of files
+      # @return [Array<Array(String, Integer)>] a list of files
       # @see #add_file
       attr_reader :files
 
@@ -189,6 +189,10 @@ module YARD
         def new(namespace, name, *args, &block)
           raise ArgumentError, "invalid empty object name" if name.to_s.empty?
           if namespace.is_a?(ConstantObject)
+            unless namespace.value =~ /\A#{NAMESPACEMATCH}\Z/
+              raise Parser::UndocumentableError, "constant mapping"
+            end
+
             namespace = Proxy.new(namespace.namespace, namespace.value)
           end
 
@@ -382,11 +386,14 @@ module YARD
       #   as a +String+ for the definition of the code object only (not the block)
       def source=(statement)
         if statement.respond_to?(:source)
-          self.signature = statement.first_line
           @source = format_source(statement.source.strip)
         else
           @source = format_source(statement.to_s)
         end
+
+        if statement.respond_to?(:signature)
+          self.signature = statement.signature
+        end
       end
 
       # The documentation string associated with the object
@@ -519,7 +526,12 @@ module YARD
         if @namespace
           reg_obj = Registry.at(path)
           return if reg_obj && reg_obj.class == self.class
-          @namespace.children << self unless @namespace.is_a?(Proxy)
+
+          unless @namespace.is_a?(Proxy)
+            # remove prior objects from obj's children that match this one
+            @namespace.children.delete_if {|o| o.path == path }
+            @namespace.children << self
+          end
           Registry.register(self)
         end
       end
