@@ -508,7 +508,7 @@ eof
 
     it "removes frozen string line from initial file comments" do
       YARD.parse_string "# frozen_string_literal: true\n# this is a comment\nclass Foo; end"
-      YARD.parse_string "# Frozen-string-literal: true\n# this is a comment\nclass Bar; end"
+      YARD.parse_string "# Frozen-string-literal: false\n# this is a comment\nclass Bar; end"
 
       expect(Registry.at(:Foo).docstring).to eq "this is a comment"
       expect(Registry.at(:Bar).docstring).to eq "this is a comment"
@@ -539,5 +539,16 @@ eof
         is_expected.to eq "#{condition_type} condition?; 42; end"
       end
     end
+
+    it "handles single-line method declaration syntax" do
+      YARD.parse_string <<-eof
+        class A
+          # Adds two numbers
+          def add(x) = x + 1
+        end
+      eof
+
+      expect(Registry.at('A#add').docstring).to eq('Adds two numbers')
+    end if RUBY_VERSION >= '3.'
   end
 end if HAVE_RIPPER
